<?php

namespace Yoast\WHIPv2\Interfaces;

/**
 * Interface MessagePresenter.
 */
interface MessagePresenter {

	/**
	 * Renders the message.
	 *
	 * @return void
	 */
	public function renderMessage();
}
